#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Créé le Thu Jan 19 17:03:00 2023

@auteur: David ALBERTO
(www.astrolabe-science.fr)
"""
from math import sqrt
import matplotlib.pyplot as plt
import numpy as np
import matplotlib as mpl#Normalisation des valeurs
import matplotlib.colorbar as cbar#barres de couleurs
from mpl_toolkits.axes_grid1 import make_axes_locatable#positionner les barres de couleurs

plt.rcParams["font.family"] = "Linux Libertine O" # ou autre police installée
plt.rcParams["font.size"] = 8

liste_logC = np.linspace(-6, -1,50)
liste_C = [pow(10,logC) for logC in liste_logC]
pKa_max = 9 # pKa maximal (pKa de 0 à pKa_max)
liste_pKa = np.linspace(0,pKa_max,pKa_max+1)
# -----------------------------------------

def alpha(pKa,C):
    """
    renvoie le taux de dissociation en %
    """
    Ka = pow(10,-pKa)
    a = C
    b = Ka
    c = -Ka
    delta = b**2-4*a*c
    x = (-b+sqrt(delta))/(2*a)*100
    return x

alpha_vect = np.vectorize(alpha)# vectorisation de la fonction, pour qu'elle accepte des listes de valeurs en argument
# ----------------
# Colormap :
#gamme de couleurs choisie (colormap) :
cmap=plt.get_cmap('brg',pKa_max)
"""
quelques colormaps :
'Greys', 'Purples', 'Blues', 'Greens', 'Oranges', 'Reds',
'YlOrBr', 'YlOrRd', 'OrRd', 'PuRd', 'RdPu', 'BuPu',
'GnBu', 'PuBu', 'YlGnBu', 'PuBuGn', 'BuGn', 'YlGn',
'cool','winter','gnuplot','brg'
"""
#normalisation de la gamme de valeurs :
norm = mpl.colors.Normalize(vmin=min(liste_pKa),vmax=max(liste_pKa))
# ----------------


fig = plt.figure(figsize=(6,4),tight_layout=True)

plt.suptitle("taux de dissociation d'un acide",y=0.95,fontsize=12)
ax1 = plt.subplot(111)
ax1.set_xlabel("C (mol/L)")
ax1.set_xlim(min(liste_C),max(liste_C))
ax1.set_xscale('log')
ax1.set_ylabel(r"$\alpha$/%",loc='top',rotation=0,va='top')
ax1.set_yticks(np.arange(0,100,10))
ax1.set_ylim(0,100)
ax1.yaxis.set_label_coords(-0.008, 1.02)# décale l'étiquette
ax1.xaxis.set_label_coords(0.50, -.035)# décale l'étiquette

ax1.grid(which='both',lw=0.25)
# ----------------------------------------------
#  tracé des courbes :

for pKa in liste_pKa:
    liste_alpha = alpha_vect(pKa, liste_C)
    ax1.plot(liste_C,liste_alpha,c=cmap(norm(pKa)),lw=1)

# ----------------------------------------------
#tracé de la barre de couleurs :
divider = make_axes_locatable(ax1)
cax = divider.append_axes('bottom', size='3%', pad=0.3)
cb=cbar.ColorbarBase(cax, cmap=cmap, norm=norm, orientation='horizontal')
cax.set_xlabel(r'$pK_a$')
cax.set_xticks(np.arange(0,pKa_max,1))
cax.xaxis.set_label_coords(0.98, -0.50)# décale l'étiquette
# ----------------------------------------------
fig.text(0.975,0.2,"D. Alberto (www.astrolabe-science.fr)",
         transform=fig.transFigure,
         rotation=90,fontsize=6,color='gray')

fig.savefig("taux_dissociation.pdf")
fig.savefig("taux_dissociation.png",dpi=300)
